@@ -7,6 +7,8 @@ def main():
 
     if len(sys.argv) == 1:
         print "USAGE: galapagos-as [-d] source.gas [source2.gas ...]"
+        print "use --ascii to get output ascii strings of 0s and 1s" \
+            "instead of real binary"
         return
 
     debug = '-d' in sys.argv
@@ -36,8 +38,14 @@ def main():
 
         ascii_binary = ''.join(ascii_binary)
 
+        ascii_mode = '--ascii' in sys.argv
+
         with open(path + '.out', 'w') as f:
-            f.write(ascii_binary_to_real_binary(ascii_binary))
+            f.write(
+                ascii_binary
+                if ascii_mode else
+                ascii_binary_to_real_binary(ascii_binary)
+            )
 
 
 if __name__ == '__main__':
